import { Ref } from 'vue'
import { Query } from '@/api/webApi'
import { CommonData, CommonTableColumn } from '~/common'

type TableDataSource =
  | 'departure'
  | 'arrival'
  | 'internationalDeparture'
  | 'internationalArrival'

const headerClassReflect = ['bg-yellow', 'bg-green', 'bg-cyan']
export default function useTableData(
  tableDataSource: TableDataSource,
  formData: CommonData,
  international: Ref<boolean>
) {
  const tableColumns = ref<CommonTableColumn[]>([])
  const tableData = ref<CommonData[]>([])
  const getTableData = async () => {
    try {
      const {
        startDate,
        endDate,
        flightStatus,
        flightWarning,
        waybillType,
      } = formData
      const dataContent = [startDate, endDate, flightStatus, flightWarning]
      if (international.value) {
        dataContent.push(waybillType)
      }
      const {
        code,
        returnData: { columnSet, listValues },
        message,
      } = await Query({
        id: DATACONTENT_ID[`${tableDataSource}Airport`],
        dataContent,
      })
      if (Number(code) !== 0) {
        throw new Error(message || '失败')
      }
      tableColumns.value = columnSet.map(column => ({
        key: column.columnName,
        dataKey: column.columnName,
        title: column.columnLabel,
        width: 200,
        align: 'center',
        ...column,
      }))
      tableData.value = listValues
    } catch (error) {
      console.error(error)
    }
  }
  onMounted(() => {
    getTableData()
  })

  return {
    tableColumns,
    tableData,
  }
}
